@@ -55,6 +55,7 @@ type Source struct {
 	includeRepos,
 	ignoreRepos []string
 	git             *git.Git
+	scanOptions     *git.ScanOptions
 	httpClient      *http.Client
 	log             logr.Logger
 	conn            *sourcespb.GitHub
@@ -67,6 +68,10 @@ type Source struct {
 	sources.Progress
 }
 
+func (s *Source) WithScanOptions(scanOptions *git.ScanOptions) {
+	s.scanOptions = scanOptions
+}
+
 // Ensure the Source satisfies the interface at compile time
 var _ sources.Source = (*Source)(nil)
 var endsWithGithub = regexp.MustCompile(`github\.com/?$`)
@@ -514,6 +519,11 @@ func (s *Source) scan(ctx context.Context, installationClient *github.Client, ch
 	reposToScan, progressIndexOffset := sources.FilterReposToResume(s.repos, s.GetProgress().EncodedResumeInfo)
 	s.repos = reposToScan
 
+	// Setup scan options if it wasn't provided.
+	if s.scanOptions == nil {
+		s.scanOptions = &git.ScanOptions{}
+	}
+
 	var scanErrs []error
 	for i, repoURL := range s.repos {
 		i, repoURL := i, repoURL
@@ -551,13 +561,11 @@ func (s *Source) scan(ctx context.Context, installationClient *github.Client, ch
 			if err != nil {
 				return nil
 			}
-			// Base and head will only exist from incoming webhooks.
-			scanOptions := git.NewScanOptions(
-				git.ScanOptionBaseHash(s.conn.Base),
-				git.ScanOptionHeadCommit(s.conn.Head),
-			)
 
-			if err = s.git.ScanRepo(ctx, repo, path, scanOptions, chunksChan); err != nil {
+			s.scanOptions.BaseHash = s.conn.Base
+			s.scanOptions.HeadHash = s.conn.Head
+
+			if err = s.git.ScanRepo(ctx, repo, path, s.scanOptions, chunksChan); err != nil {
 				logger.Error(err, "unable to scan repo, continuing")
 				return nil
 			}
